==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_fields/ALERTFIELDID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ALERTFIELDID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ALERTFIELDID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDALIAS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDLABEL" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTFIELDID_Type", propOrder = {
    "gridfieldcode",
    "gridfieldalias",
    "gridfieldlabel"
})
public class ALERTFIELDID_Type {

    @XmlElement(name = "GRIDFIELDCODE")
    protected long gridfieldcode;
    @XmlElement(name = "GRIDFIELDALIAS")
    protected String gridfieldalias;
    @XmlElement(name = "GRIDFIELDLABEL")
    protected String gridfieldlabel;

    /**
     * Obtient la valeur de la propriété gridfieldcode.
     * 
     */
    public long getGRIDFIELDCODE() {
        return gridfieldcode;
    }

    /**
     * Définit la valeur de la propriété gridfieldcode.
     * 
     */
    public void setGRIDFIELDCODE(long value) {
        this.gridfieldcode = value;
    }

    /**
     * Obtient la valeur de la propriété gridfieldalias.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDFIELDALIAS() {
        return gridfieldalias;
    }

    /**
     * Définit la valeur de la propriété gridfieldalias.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDFIELDALIAS(String value) {
        this.gridfieldalias = value;
    }

    /**
     * Obtient la valeur de la propriété gridfieldlabel.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDFIELDLABEL() {
        return gridfieldlabel;
    }

    /**
     * Définit la valeur de la propriété gridfieldlabel.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDFIELDLABEL(String value) {
        this.gridfieldlabel = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/ALERTFIELDID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ALERTFIELDID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ALERTFIELDID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDALIAS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDLABEL" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTFIELDID_Type", propOrder = {
    "gridfieldcode",
    "gridfieldalias",
    "gridfieldlabel"
})
public class ALERTFIELDID_Type {

    @XmlElement(name = "GRIDFIELDCODE")
    protected long gridfieldcode;
    @XmlElement(name = "GRIDFIELDALIAS")
    protected String gridfieldalias;
    @XmlElement(name = "GRIDFIELDLABEL")
    protected String gridfieldlabel;

    /**
     * Gets the value of the gridfieldcode property.
     * 
     */
    public long getGRIDFIELDCODE() {
        return gridfieldcode;
    }

    /**
     * Sets the value of the gridfieldcode property.
     * 
     */
    public void setGRIDFIELDCODE(long value) {
        this.gridfieldcode = value;
    }

    /**
     * Gets the value of the gridfieldalias property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDFIELDALIAS() {
        return gridfieldalias;
    }

    /**
     * Sets the value of the gridfieldalias property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDFIELDALIAS(String value) {
        this.gridfieldalias = value;
    }

    /**
     * Gets the value of the gridfieldlabel property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDFIELDLABEL() {
        return gridfieldlabel;
    }

    /**
     * Sets the value of the gridfieldlabel property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDFIELDLABEL(String value) {
        this.gridfieldlabel = value;
    }

}
